// XYZ frame for pick and place unit

// XYZ system parameters
frame=[690, 910, 270]; // frame XYZ
beam=[40, 40]; // beam size XY
xpos= 910/2; // Position of the X-gantry for imaging (could be animated!)

// T-slot beam module with or without motor
module tslot(length=100, startposition=[0,0,0], rotation=[0,0,0]){
    color("silver")translate(startposition) rotate(rotation) linear_extrude(height = length, center = false, convexity = 1)
    import (file = "profile2.dxf", layer = "0");  
}
// Draw up the basic beams (parameterized)
tslot(frame[1],[0,0,0],[0,90,0]);
tslot(frame[1],[0,frame[0]-2*(beam[0]),0],[0,90,0]);
tslot(frame[0]-3*(beam[0]),[0,beam[0],0],[-90,0,0]);
tslot(frame[0]-3*(beam[0]),[frame[1]-(beam[0]),beam[0],0],[-90,0,0]);
// add the X-beam at height 300 - beam height mm 
tslot(frame[0],[xpos,0,(frame[2]-beam[1])],[-90,0,0]);

// Add the Y gantry module
module ygantry(length=10, startposition=[0,0,0], rotation=[0,0,0]){
    color("darkorange")translate(startposition) rotate(rotation) linear_extrude(height = length, center = false, convexity = 1)
    import (file = "ygantry.dxf", layer = "0");  
}

// Add the side panels Y Gantry mockup
ygantry(10,[xpos-0.5*beam[1],0,-1.5*beam[1]],[90,0,0]);

ygantry(10,[xpos-0.5*beam[1],frame[0]-beam[0]+10,-1.5*beam[1]],[90,0,0]);

// Adding the NEMA motors from the MCAD library
// https://github.com/openscad/MCAD/blob/master/stepper.scad
include <MCAD/stepper.scad>
// Y-Motor
translate([(beam[0])/2,frame[0]-(beam[0]),-20]) rotate([-90,0,0]) motor(Nema17, NemaMedium, dualAxis=false);
// X motor
translate([xpos,frame[0]-(.5*beam[0])+10,frame[2]-1.5*beam[0]]) rotate([-90,0,90]) motor(Nema17, NemaMedium, dualAxis=false);
//translate([20,frame[0],300]) rotate([-90,0,0]) motor(Nema17, NemaMedium, dualAxis=-1)

// Import beveled helical gear example
module rotorhead(size=100, startposition=[0,0,0], rotation=[0,90,0]){
    color("white")translate(startposition)rotate(rotation)
    resize([size,0,0], auto=true) import("Helical_Bevel_Gear_Pair.stl", convexity=10);  
}

rotorhead(150,[xpos+2.5*beam[0],0.5*frame[0],frame[2]-1.5*beam[0]]) rotate([0,0,0]);


